@@ -1,9 +1,9 @@
 import time
 
-__version__ = "1.1.2"
+__version__ = "2.1.1"
 "Module version string."
 
-version = (1, 1, 2)
+version = (2, 1, 1)
 "Module version tuple."
 
 
@@ -37,7 +37,7 @@ def sleep_us(microseconds):
     time.sleep(microseconds / 1000000.0)
 
 
-from periphery.gpio import GPIO, GPIOError
+from periphery.gpio import GPIO, SysfsGPIO, CdevGPIO, EdgeEvent, GPIOError
 from periphery.led import LED, LEDError
 from periphery.pwm import PWM, PWMError
 from periphery.spi import SPI, SPIError
